@@ -5,6 +5,27 @@ import numpy as np
 from d3graph import d3graph
 
 
+# %%
+from d3graph import d3graph
+d3 = d3graph()
+adjmat = d3.import_example('bigbang')
+d3.graph(adjmat)
+d3.set_node_properties(color='', label=adjmat.columns.values+' are the names', hover=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
+d3.set_node_properties(color=[], label=adjmat.columns.values+' are the names', hover=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
+d3.set_node_properties(color=['#000000', '#000000', '#000000', '#000', '#000000', '#000000', '#000000'], label=adjmat.columns.values+' are the names', hover=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
+d3.set_node_properties(color=['#000000', '#000000', '#000000', '#000000', '#000000', '#000000'], label=adjmat.columns.values+' are the names', hover=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
+d3.set_node_properties(color=['#000000', '#000000', '#00', '#000000', '#000000', '#000000'], label=adjmat.columns.values+' are the names', hover=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
+d3.show()
+
+# %%
+from d3graph import d3graph
+
+d3 = d3graph()
+adjmat = d3.import_example('bigbang')
+d3.graph(adjmat)
+d3.set_node_properties(label=adjmat.columns.values+' are the names', hover=['\nFemale\nMore info', 'Female', 'Male', 'Male', 'Female', 'Male', 'Male'])
+d3.show()
+
 # %%
 from d3graph import d3graph
 
@@ -43,7 +64,6 @@ d3.show(showfig=True)
 
 # %%
 
-
 # Make some graphs
 d3 = d3graph()
 # Load example
